@@ -9,12 +9,12 @@ from click_didyoumean import DYMGroup
 from plumbum.cmd import cp
 from plumbum.colors import blue, green, red, white, yellow  # noqa: F401
 
-from openapi_cli.interfaces.main import cli
-from openapi_cli.symbols import BACKUP, BAD, FILE, INFO, MAGNIFIER, OK, WRITE
 from openapi_cli.helpers import echo, get_script_name
+from openapi_cli.interfaces.configure import configure
+from openapi_cli.symbols import BACKUP, BAD, FILE, INFO, MAGNIFIER, OK, WRITE
 
 
-@cli.group("completions", cls=DYMGroup)
+@configure.group("completions", cls=DYMGroup)
 def completions_group():
     """Terminal completion commands."""
 
@@ -128,7 +128,7 @@ def completions_disable(ctx: Context, shell: str):
     """Disable completions for the CLI."""
 
     rc_path, rc_command, script_rc_path, script_command = get_shell_info(
-        ctx.parent.parent.info_name, shell=shell
+        get_script_name(ctx), shell=shell
     )
 
     if script_rc_path.exists():
